Class: Aws::TimestreamInfluxDB::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::TimestreamInfluxDB::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/client.rb
Overview
An API client for TimestreamInfluxDB. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::TimestreamInfluxDB::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_db_cluster(params = {}) ⇒ Types::CreateDbClusterOutput
Creates a new Timestream for InfluxDB cluster.
-
#create_db_instance(params = {}) ⇒ Types::CreateDbInstanceOutput
Creates a new Timestream for InfluxDB DB instance.
-
#create_db_parameter_group(params = {}) ⇒ Types::CreateDbParameterGroupOutput
Creates a new Timestream for InfluxDB DB parameter group to associate with DB instances.
-
#delete_db_cluster(params = {}) ⇒ Types::DeleteDbClusterOutput
Deletes a Timestream for InfluxDB cluster.
-
#delete_db_instance(params = {}) ⇒ Types::DeleteDbInstanceOutput
Deletes a Timestream for InfluxDB DB instance.
-
#get_db_cluster(params = {}) ⇒ Types::GetDbClusterOutput
Retrieves information about a Timestream for InfluxDB cluster.
-
#get_db_instance(params = {}) ⇒ Types::GetDbInstanceOutput
Returns a Timestream for InfluxDB DB instance.
-
#get_db_parameter_group(params = {}) ⇒ Types::GetDbParameterGroupOutput
Returns a Timestream for InfluxDB DB parameter group.
-
#list_db_clusters(params = {}) ⇒ Types::ListDbClustersOutput
Returns a list of Timestream for InfluxDB DB clusters.
-
#list_db_instances(params = {}) ⇒ Types::ListDbInstancesOutput
Returns a list of Timestream for InfluxDB DB instances.
-
#list_db_instances_for_cluster(params = {}) ⇒ Types::ListDbInstancesForClusterOutput
Returns a list of Timestream for InfluxDB clusters.
-
#list_db_parameter_groups(params = {}) ⇒ Types::ListDbParameterGroupsOutput
Returns a list of Timestream for InfluxDB DB parameter groups.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of tags applied to the resource.
-
#tag_resource(params = {}) ⇒ Struct
Tags are composed of a Key/Value pairs.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tag from the specified resource.
-
#update_db_cluster(params = {}) ⇒ Types::UpdateDbClusterOutput
Updates a Timestream for InfluxDB cluster.
-
#update_db_instance(params = {}) ⇒ Types::UpdateDbInstanceOutput
Updates a Timestream for InfluxDB DB instance.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
483 484 485 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 483 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1782 1783 1784 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1782 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1785 1786 1787 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1785 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1755 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::TimestreamInfluxDB') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-timestreaminfluxdb' context[:gem_version] = '1.27.0' Seahorse::Client::Request.new(handlers, context) end |
#create_db_cluster(params = {}) ⇒ Types::CreateDbClusterOutput
Creates a new Timestream for InfluxDB cluster.
634 635 636 637 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 634 def create_db_cluster(params = {}, = {}) req = build_request(:create_db_cluster, params) req.send_request() end |
#create_db_instance(params = {}) ⇒ Types::CreateDbInstanceOutput
Creates a new Timestream for InfluxDB DB instance.
819 820 821 822 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 819 def create_db_instance(params = {}, = {}) req = build_request(:create_db_instance, params) req.send_request() end |
#create_db_parameter_group(params = {}) ⇒ Types::CreateDbParameterGroupOutput
Creates a new Timestream for InfluxDB DB parameter group to associate with DB instances.
973 974 975 976 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 973 def create_db_parameter_group(params = {}, = {}) req = build_request(:create_db_parameter_group, params) req.send_request() end |
#delete_db_cluster(params = {}) ⇒ Types::DeleteDbClusterOutput
Deletes a Timestream for InfluxDB cluster.
1001 1002 1003 1004 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1001 def delete_db_cluster(params = {}, = {}) req = build_request(:delete_db_cluster, params) req.send_request() end |
#delete_db_instance(params = {}) ⇒ Types::DeleteDbInstanceOutput
Deletes a Timestream for InfluxDB DB instance.
1072 1073 1074 1075 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1072 def delete_db_instance(params = {}, = {}) req = build_request(:delete_db_instance, params) req.send_request() end |
#get_db_cluster(params = {}) ⇒ Types::GetDbClusterOutput
Retrieves information about a Timestream for InfluxDB cluster.
1139 1140 1141 1142 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1139 def get_db_cluster(params = {}, = {}) req = build_request(:get_db_cluster, params) req.send_request() end |
#get_db_instance(params = {}) ⇒ Types::GetDbInstanceOutput
Returns a Timestream for InfluxDB DB instance.
1210 1211 1212 1213 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1210 def get_db_instance(params = {}, = {}) req = build_request(:get_db_instance, params) req.send_request() end |
#get_db_parameter_group(params = {}) ⇒ Types::GetDbParameterGroupOutput
Returns a Timestream for InfluxDB DB parameter group.
1287 1288 1289 1290 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1287 def get_db_parameter_group(params = {}, = {}) req = build_request(:get_db_parameter_group, params) req.send_request() end |
#list_db_clusters(params = {}) ⇒ Types::ListDbClustersOutput
Returns a list of Timestream for InfluxDB DB clusters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1339 1340 1341 1342 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1339 def list_db_clusters(params = {}, = {}) req = build_request(:list_db_clusters, params) req.send_request() end |
#list_db_instances(params = {}) ⇒ Types::ListDbInstancesOutput
Returns a list of Timestream for InfluxDB DB instances.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1390 1391 1392 1393 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1390 def list_db_instances(params = {}, = {}) req = build_request(:list_db_instances, params) req.send_request() end |
#list_db_instances_for_cluster(params = {}) ⇒ Types::ListDbInstancesForClusterOutput
Returns a list of Timestream for InfluxDB clusters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1446 1447 1448 1449 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1446 def list_db_instances_for_cluster(params = {}, = {}) req = build_request(:list_db_instances_for_cluster, params) req.send_request() end |
#list_db_parameter_groups(params = {}) ⇒ Types::ListDbParameterGroupsOutput
Returns a list of Timestream for InfluxDB DB parameter groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1490 1491 1492 1493 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1490 def list_db_parameter_groups(params = {}, = {}) req = build_request(:list_db_parameter_groups, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of tags applied to the resource.
1519 1520 1521 1522 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1519 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags are composed of a Key/Value pairs. You can use tags to categorize and track your Timestream for InfluxDB resources.
1548 1549 1550 1551 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1548 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the tag from the specified resource.
1574 1575 1576 1577 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1574 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_db_cluster(params = {}) ⇒ Types::UpdateDbClusterOutput
Updates a Timestream for InfluxDB cluster.
1627 1628 1629 1630 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1627 def update_db_cluster(params = {}, = {}) req = build_request(:update_db_cluster, params) req.send_request() end |
#update_db_instance(params = {}) ⇒ Types::UpdateDbInstanceOutput
Updates a Timestream for InfluxDB DB instance.
1746 1747 1748 1749 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1746 def update_db_instance(params = {}, = {}) req = build_request(:update_db_instance, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1775 1776 1777 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1775 def waiter_names [] end |