Class: Aws::TimestreamInfluxDB::Types::CreateDbClusterInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::CreateDbClusterInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username, :password]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The amount of storage to allocate for your DB storage type in GiB (gibibytes).
-
#bucket ⇒ String
The name of the initial InfluxDB bucket.
-
#db_backup_configurations ⇒ Array<Types::DbBackupConfiguration>
A list of backup configurations to enable automated backups for the DB cluster.
-
#db_instance_type ⇒ String
The Timestream for InfluxDB DB instance type to run InfluxDB on.
-
#db_parameter_group_identifier ⇒ String
The ID of the DB parameter group to assign to your DB cluster.
-
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type to read and write InfluxDB data.
-
#deployment_type ⇒ String
Specifies the type of cluster to create.
-
#failover_mode ⇒ String
Specifies the behavior of failure recovery when the primary node of the cluster fails.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier to use for encryption of the DB cluster.
-
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to a specified S3 bucket.
-
#maintenance_schedule ⇒ Types::MaintenanceSchedule
Specifies the maintenance schedule for the DB cluster, including the preferred maintenance window and timezone.
-
#name ⇒ String
The name that uniquely identifies the DB cluster when interacting with the Amazon Timestream for InfluxDB API and CLI commands.
-
#network_type ⇒ String
Specifies whether the network type of the Timestream for InfluxDB cluster is IPv4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
-
#organization ⇒ String
The name of the initial organization for the initial admin user in InfluxDB.
-
#password ⇒ String
The password of the initial admin user created in InfluxDB.
-
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
-
#publicly_accessible ⇒ Boolean
Configures the Timestream for InfluxDB cluster with a public IP to facilitate access from outside the VPC.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs to associate with the DB instance.
-
#username ⇒ String
The username of the initial admin user created in InfluxDB.
-
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security group IDs to associate with the Timestream for InfluxDB cluster.
-
#vpc_subnet_ids ⇒ Array<String>
A list of VPC subnet IDs to associate with the DB cluster.
Instance Attribute Details
#allocated_storage ⇒ Integer
The amount of storage to allocate for your DB storage type in GiB (gibibytes).
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#bucket ⇒ String
The name of the initial InfluxDB bucket. All InfluxDB data is stored in a bucket. A bucket combines the concept of a database and a retention period (the duration of time that each data point persists). A bucket belongs to an organization.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#db_backup_configurations ⇒ Array<Types::DbBackupConfiguration>
A list of backup configurations to enable automated backups for the DB cluster.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#db_instance_type ⇒ String
The Timestream for InfluxDB DB instance type to run InfluxDB on.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#db_parameter_group_identifier ⇒ String
The ID of the DB parameter group to assign to your DB cluster. DB parameter groups specify how the database is configured. For example, DB parameter groups can specify the limit for query concurrency.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type to read and write InfluxDB data.
You can choose between three different types of provisioned Influx IOPS Included storage according to your workload requirements:
-
Influx I/O Included 3000 IOPS
-
Influx I/O Included 12000 IOPS
-
Influx I/O Included 16000 IOPS
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#deployment_type ⇒ String
Specifies the type of cluster to create.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#failover_mode ⇒ String
Specifies the behavior of failure recovery when the primary node of the cluster fails.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier to use for encryption of the DB cluster. Can be a key ID, key ARN, alias name, or alias ARN.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to a specified S3 bucket.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#maintenance_schedule ⇒ Types::MaintenanceSchedule
Specifies the maintenance schedule for the DB cluster, including the preferred maintenance window and timezone.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#name ⇒ String
The name that uniquely identifies the DB cluster when interacting with the Amazon Timestream for InfluxDB API and CLI commands. This name will also be a prefix included in the endpoint. DB cluster names must be unique per customer and per region.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#network_type ⇒ String
Specifies whether the network type of the Timestream for InfluxDB cluster is IPv4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#organization ⇒ String
The name of the initial organization for the initial admin user in InfluxDB. An InfluxDB organization is a workspace for a group of users.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#password ⇒ String
The password of the initial admin user created in InfluxDB. This password will allow you to access the InfluxDB UI to perform various administrative tasks and also use the InfluxDB CLI to create an operator token. These attributes will be stored in a secret created in Secrets Manager in your account.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
Valid Values: 1024-65535
Default: 8086 for InfluxDB v2, 8181 for InfluxDB v3
Constraints: The value can't be 2375-2376, 7788-7799, 8090, or 51678-51680
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#publicly_accessible ⇒ Boolean
Configures the Timestream for InfluxDB cluster with a public IP to facilitate access from outside the VPC.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs to associate with the DB instance.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#username ⇒ String
The username of the initial admin user created in InfluxDB. Must start with a letter and can't end with a hyphen or contain two consecutive hyphens. For example, my-user1. This username will allow you to access the InfluxDB UI to perform various administrative tasks and also use the InfluxDB CLI to create an operator token. These attributes will be stored in a secret created in Secrets Manager in your account.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security group IDs to associate with the Timestream for InfluxDB cluster.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |
#vpc_subnet_ids ⇒ Array<String>
A list of VPC subnet IDs to associate with the DB cluster. Provide at least two VPC subnet IDs in different Availability Zones when deploying with a Multi-AZ standby.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 380 class CreateDbClusterInput < Struct.new( :name, :username, :password, :organization, :bucket, :port, :db_parameter_group_identifier, :db_instance_type, :db_storage_type, :allocated_storage, :network_type, :publicly_accessible, :vpc_subnet_ids, :vpc_security_group_ids, :deployment_type, :failover_mode, :log_delivery_configuration, :maintenance_schedule, :db_backup_configurations, :kms_key_id, :tags) SENSITIVE = [:username, :password] include Aws::Structure end |