Class: Aws::TimestreamInfluxDB::Types::CreateDbInstanceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::CreateDbInstanceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username, :password]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The amount of storage to allocate for your DB storage type in GiB (gibibytes).
-
#bucket ⇒ String
The name of the initial InfluxDB bucket.
-
#db_backup_configurations ⇒ Array<Types::DbBackupConfiguration>
A list of backup configurations to enable automated backups for the DB instance.
-
#db_instance_type ⇒ String
The Timestream for InfluxDB DB instance type to run InfluxDB on.
-
#db_parameter_group_identifier ⇒ String
The id of the DB parameter group to assign to your DB instance.
-
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type to read and write InfluxDB data.
-
#deployment_type ⇒ String
Specifies whether the DB instance will be deployed as a standalone instance or with a Multi-AZ standby for high availability.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier to use for encryption of the DB instance.
-
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to a specified S3 bucket.
-
#maintenance_schedule ⇒ Types::MaintenanceSchedule
Specifies the maintenance schedule for the DB instance, including the preferred maintenance window and timezone.
-
#name ⇒ String
The name that uniquely identifies the DB instance when interacting with the Amazon Timestream for InfluxDB API and CLI commands.
-
#network_type ⇒ String
Specifies whether the networkType of the Timestream for InfluxDB instance is IPV4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
-
#organization ⇒ String
The name of the initial organization for the initial admin user in InfluxDB.
-
#password ⇒ String
The password of the initial admin user created in InfluxDB v2.
-
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
-
#publicly_accessible ⇒ Boolean
Configures the DB instance with a public IP to facilitate access.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs to associate with the DB instance.
-
#username ⇒ String
The username of the initial admin user created in InfluxDB.
-
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security group IDs to associate with the DB instance.
-
#vpc_subnet_ids ⇒ Array<String>
A list of VPC subnet IDs to associate with the DB instance.
Instance Attribute Details
#allocated_storage ⇒ Integer
The amount of storage to allocate for your DB storage type in GiB (gibibytes).
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#bucket ⇒ String
The name of the initial InfluxDB bucket. All InfluxDB data is stored in a bucket. A bucket combines the concept of a database and a retention period (the duration of time that each data point persists). A bucket belongs to an organization.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#db_backup_configurations ⇒ Array<Types::DbBackupConfiguration>
A list of backup configurations to enable automated backups for the DB instance.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#db_instance_type ⇒ String
The Timestream for InfluxDB DB instance type to run InfluxDB on.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#db_parameter_group_identifier ⇒ String
The id of the DB parameter group to assign to your DB instance. DB parameter groups specify how the database is configured. For example, DB parameter groups can specify the limit for query concurrency.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type to read and write InfluxDB data.
You can choose between 3 different types of provisioned Influx IOPS included storage according to your workloads requirements:
-
Influx IO Included 3000 IOPS
-
Influx IO Included 12000 IOPS
-
Influx IO Included 16000 IOPS
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#deployment_type ⇒ String
Specifies whether the DB instance will be deployed as a standalone instance or with a Multi-AZ standby for high availability.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier to use for encryption of the DB instance. Can be a key ID, key ARN, alias name, or alias ARN.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to a specified S3 bucket.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#maintenance_schedule ⇒ Types::MaintenanceSchedule
Specifies the maintenance schedule for the DB instance, including the preferred maintenance window and timezone.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#name ⇒ String
The name that uniquely identifies the DB instance when interacting with the Amazon Timestream for InfluxDB API and CLI commands. This name will also be a prefix included in the endpoint. DB instance names must be unique per customer and per region.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#network_type ⇒ String
Specifies whether the networkType of the Timestream for InfluxDB instance is IPV4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#organization ⇒ String
The name of the initial organization for the initial admin user in InfluxDB. An InfluxDB organization is a workspace for a group of users.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#password ⇒ String
The password of the initial admin user created in InfluxDB v2. This password will allow you to access the InfluxDB UI to perform various administrative tasks and also use the InfluxDB CLI to create an operator token. These attributes will be stored in a Secret created in Secrets Manager in your account.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
Valid Values: 1024-65535
Default: 8086
Constraints: The value can't be 2375-2376, 7788-7799, 8090, or 51678-51680
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#publicly_accessible ⇒ Boolean
Configures the DB instance with a public IP to facilitate access.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs to associate with the DB instance.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#username ⇒ String
The username of the initial admin user created in InfluxDB. Must start with a letter and can't end with a hyphen or contain two consecutive hyphens. For example, my-user1. This username will allow you to access the InfluxDB UI to perform various administrative tasks and also use the InfluxDB CLI to create an operator token. These attributes will be stored in a Secret created in Amazon Secrets Manager in your account.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security group IDs to associate with the DB instance.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |
#vpc_subnet_ids ⇒ Array<String>
A list of VPC subnet IDs to associate with the DB instance. Provide at least two VPC subnet IDs in different availability zones when deploying with a Multi-AZ standby.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 553 class CreateDbInstanceInput < Struct.new( :name, :username, :password, :organization, :bucket, :db_instance_type, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :db_storage_type, :allocated_storage, :db_parameter_group_identifier, :deployment_type, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [:username, :password] include Aws::Structure end |