Class: Aws::TimestreamInfluxDB::Types::CreateDbInstanceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::CreateDbInstanceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The amount of storage allocated for your DB storage type (in gibibytes).
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the DB instance.
-
#availability_zone ⇒ String
The Availability Zone in which the DB instance resides.
-
#db_backup_configurations ⇒ Array<Types::DbBackupConfigurationOutput>
The backup configurations for the DB instance.
-
#db_cluster_id ⇒ String
Specifies the DbCluster to which this DbInstance belongs to.
-
#db_instance_type ⇒ String
The Timestream for InfluxDB instance type that InfluxDB runs on.
-
#db_parameter_group_identifier ⇒ String
The id of the DB parameter group assigned to your DB instance.
-
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type that InfluxDB stores data on.
-
#deployment_type ⇒ String
Specifies whether the Timestream for InfluxDB is deployed as Single-AZ or with a MultiAZ Standby for High availability.
-
#endpoint ⇒ String
The endpoint used to connect to InfluxDB.
-
#id ⇒ String
A service-generated unique identifier.
-
#influx_auth_parameters_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the Secrets Manager secret containing the initial InfluxDB authorization parameters.
-
#instance_mode ⇒ String
Specifies the DbInstance's role in the cluster.
-
#instance_modes ⇒ Array<String>
Specifies the DbInstance's roles in the cluster.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key ARN used for encryption of the DB instance.
-
#last_maintenance_time ⇒ Time
The timestamp of the last completed maintenance operation on the DB instance.
-
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to send to specified S3 bucket.
-
#maintenance_schedule ⇒ Types::MaintenanceSchedule
The maintenance schedule for the DB instance.
-
#name ⇒ String
The customer-supplied name that uniquely identifies the DB instance when interacting with the Amazon Timestream for InfluxDB API and CLI commands.
-
#network_type ⇒ String
Specifies whether the networkType of the Timestream for InfluxDB instance is IPV4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
-
#next_maintenance_time ⇒ Time
The timestamp of the next scheduled maintenance operation on the DB instance.
-
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
-
#publicly_accessible ⇒ Boolean
Indicates if the DB instance has a public IP to facilitate access.
-
#secondary_availability_zone ⇒ String
The Availability Zone in which the standby instance is located when deploying with a MultiAZ standby instance.
-
#status ⇒ String
The status of the DB instance.
-
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security group IDs associated with the DB instance.
-
#vpc_subnet_ids ⇒ Array<String>
A list of VPC subnet IDs associated with the DB instance.
Instance Attribute Details
#allocated_storage ⇒ Integer
The amount of storage allocated for your DB storage type (in gibibytes).
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the DB instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone in which the DB instance resides.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#db_backup_configurations ⇒ Array<Types::DbBackupConfigurationOutput>
The backup configurations for the DB instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#db_cluster_id ⇒ String
Specifies the DbCluster to which this DbInstance belongs to.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#db_instance_type ⇒ String
The Timestream for InfluxDB instance type that InfluxDB runs on.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#db_parameter_group_identifier ⇒ String
The id of the DB parameter group assigned to your DB instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type that InfluxDB stores data on.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#deployment_type ⇒ String
Specifies whether the Timestream for InfluxDB is deployed as Single-AZ or with a MultiAZ Standby for High availability.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The endpoint used to connect to InfluxDB. The default InfluxDB port is 8086.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A service-generated unique identifier.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#influx_auth_parameters_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the Secrets Manager secret containing the initial InfluxDB authorization parameters. The secret value is a JSON formatted key-value pair holding InfluxDB authorization values: organization, bucket, username, and password.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#instance_mode ⇒ String
Specifies the DbInstance's role in the cluster.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#instance_modes ⇒ Array<String>
Specifies the DbInstance's roles in the cluster.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key ARN used for encryption of the DB instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#last_maintenance_time ⇒ Time
The timestamp of the last completed maintenance operation on the DB instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to send to specified S3 bucket.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#maintenance_schedule ⇒ Types::MaintenanceSchedule
The maintenance schedule for the DB instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The customer-supplied name that uniquely identifies the DB instance when interacting with the Amazon Timestream for InfluxDB API and CLI commands.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
Specifies whether the networkType of the Timestream for InfluxDB instance is IPV4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#next_maintenance_time ⇒ Time
The timestamp of the next scheduled maintenance operation on the DB instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which InfluxDB accepts connections. The default value is 8086.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#publicly_accessible ⇒ Boolean
Indicates if the DB instance has a public IP to facilitate access.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#secondary_availability_zone ⇒ String
The Availability Zone in which the standby instance is located when deploying with a MultiAZ standby instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the DB instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security group IDs associated with the DB instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#vpc_subnet_ids ⇒ Array<String>
A list of VPC subnet IDs associated with the DB instance.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 705 class CreateDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn, :db_cluster_id, :instance_mode, :instance_modes, :maintenance_schedule, :last_maintenance_time, :next_maintenance_time, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |