Class: Aws::TimestreamInfluxDB::Types::DbBackupConfigurationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Contains the configuration and status for an automated backup schedule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_scheduleString

The custom cron schedule expression for the backup, if applicable.

Returns:

  • (String)


856
857
858
859
860
861
862
863
864
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 856

class DbBackupConfigurationOutput < Struct.new(
  :type,
  :retention_days,
  :enabled,
  :custom_schedule,
  :next_automated_backup_time)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Indicates whether this backup configuration is enabled.

Returns:

  • (Boolean)


856
857
858
859
860
861
862
863
864
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 856

class DbBackupConfigurationOutput < Struct.new(
  :type,
  :retention_days,
  :enabled,
  :custom_schedule,
  :next_automated_backup_time)
  SENSITIVE = []
  include Aws::Structure
end

#next_automated_backup_timeTime

The next scheduled time for an automated backup to be taken.

Returns:

  • (Time)


856
857
858
859
860
861
862
863
864
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 856

class DbBackupConfigurationOutput < Struct.new(
  :type,
  :retention_days,
  :enabled,
  :custom_schedule,
  :next_automated_backup_time)
  SENSITIVE = []
  include Aws::Structure
end

#retention_daysInteger

The number of days automated backups are retained.

Returns:

  • (Integer)


856
857
858
859
860
861
862
863
864
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 856

class DbBackupConfigurationOutput < Struct.new(
  :type,
  :retention_days,
  :enabled,
  :custom_schedule,
  :next_automated_backup_time)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of automated backup schedule.

Returns:

  • (String)


856
857
858
859
860
861
862
863
864
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 856

class DbBackupConfigurationOutput < Struct.new(
  :type,
  :retention_days,
  :enabled,
  :custom_schedule,
  :next_automated_backup_time)
  SENSITIVE = []
  include Aws::Structure
end