Class: Aws::TimestreamInfluxDB::Types::DbBackupSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Contains a summary of a Timestream for InfluxDB backup.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the backup.

Returns:

  • (String)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time when the backup was created.

Returns:

  • (Time)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_resource_idString

The identifier of the DB resource that the backup was created from.

Returns:

  • (String)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_typeString

The deployment type of the resource that the backup was created from.

Returns:

  • (String)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#engine_typeString

The engine type of the resource that the backup was created from.

Returns:

  • (String)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#expires_afterString

The date after which the backup will be automatically deleted.

Returns:

  • (String)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Service-generated unique identifier of the backup.

Returns:

  • (String)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Web Services KMS key ARN used for encryption of the resource at the time of backup.

Returns:

  • (String)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The customer-provided name of the backup.

Returns:

  • (String)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the backup. Valid values are IN_PROGRESS, COMPLETED, FAILED, DELETING, and DELETED.

Returns:

  • (String)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of backup. Valid values are HOURLY, DAILY, WEEKLY, MONTHLY, CUSTOM_SCHEDULE, ON_DEMAND, and CONTINUOUS.

Returns:

  • (String)


918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918

class DbBackupSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end