Class: Aws::TimestreamInfluxDB::Types::DbClusterSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::DbClusterSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Describes a summary of a Timestream for InfluxDB cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The amount of storage allocated for your DB storage type (in gibibytes).
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the DB cluster.
-
#db_instance_type ⇒ String
The Timestream for InfluxDB DB instance type that InfluxDB runs on.
-
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type that InfluxDB stores data on.
-
#deployment_type ⇒ String
Deployment type of the DB cluster.
-
#endpoint ⇒ String
The endpoint used to connect to the Timestream for InfluxDB cluster for write and read operations.
-
#engine_type ⇒ String
The engine type of your DB cluster.
-
#id ⇒ String
Service-generated unique identifier of the DB cluster to retrieve.
-
#name ⇒ String
Customer supplied name of the Timestream for InfluxDB cluster.
-
#network_type ⇒ String
Specifies whether the network type of the Timestream for InfluxDB Cluster is IPv4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
-
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
-
#reader_endpoint ⇒ String
The endpoint used to connect to the Timestream for InfluxDB cluster for read-only operations.
-
#status ⇒ String
The status of the DB cluster.
Instance Attribute Details
#allocated_storage ⇒ Integer
The amount of storage allocated for your DB storage type (in gibibytes).
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the DB cluster.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#db_instance_type ⇒ String
The Timestream for InfluxDB DB instance type that InfluxDB runs on.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type that InfluxDB stores data on.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#deployment_type ⇒ String
Deployment type of the DB cluster
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The endpoint used to connect to the Timestream for InfluxDB cluster for write and read operations.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#engine_type ⇒ String
The engine type of your DB cluster.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Service-generated unique identifier of the DB cluster to retrieve.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Customer supplied name of the Timestream for InfluxDB cluster.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
Specifies whether the network type of the Timestream for InfluxDB Cluster is IPv4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#reader_endpoint ⇒ String
The endpoint used to connect to the Timestream for InfluxDB cluster for read-only operations.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the DB cluster.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 996 class DbClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :reader_endpoint, :port, :deployment_type, :db_instance_type, :network_type, :db_storage_type, :allocated_storage, :engine_type) SENSITIVE = [] include Aws::Structure end |