Class: Aws::TimestreamInfluxDB::Types::DbInstanceForClusterSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::DbInstanceForClusterSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Contains a summary of a DB instance belonging to a DB cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The amount of storage allocated for your DB storage type in GiB (gibibytes).
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the DB instance.
-
#db_instance_type ⇒ String
The Timestream for InfluxDB instance type to run InfluxDB on.
-
#db_storage_type ⇒ String
The storage type for your DB instance.
-
#deployment_type ⇒ String
Specifies the deployment type if applicable.
-
#endpoint ⇒ String
The endpoint used to connect to InfluxDB.
-
#id ⇒ String
The service-generated unique identifier of the DB instance.
-
#instance_mode ⇒ String
Specifies the DB instance's role in the cluster.
-
#instance_modes ⇒ Array<String>
Specifies the DB instance's roles in the cluster.
-
#name ⇒ String
A service-generated name for the DB instance based on the customer-supplied name for the DB cluster.
-
#network_type ⇒ String
Specifies whether the network type of the Timestream for InfluxDB instance is IPv4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
-
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
-
#status ⇒ String
The status of the DB instance.
Instance Attribute Details
#allocated_storage ⇒ Integer
The amount of storage allocated for your DB storage type in GiB (gibibytes).
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the DB instance.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#db_instance_type ⇒ String
The Timestream for InfluxDB instance type to run InfluxDB on.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#db_storage_type ⇒ String
The storage type for your DB instance.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#deployment_type ⇒ String
Specifies the deployment type if applicable.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The endpoint used to connect to InfluxDB. The default InfluxDB port is 8086.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The service-generated unique identifier of the DB instance.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#instance_mode ⇒ String
Specifies the DB instance's role in the cluster.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#instance_modes ⇒ Array<String>
Specifies the DB instance's roles in the cluster.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A service-generated name for the DB instance based on the customer-supplied name for the DB cluster.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
Specifies whether the network type of the Timestream for InfluxDB instance is IPv4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the DB instance.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1075 class DbInstanceForClusterSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :instance_mode, :instance_modes) SENSITIVE = [] include Aws::Structure end |