Class: Aws::TimestreamInfluxDB::Types::DbInstanceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Contains a summary of a DB instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

The amount of storage to allocate for your DbStorageType in GiB (gibibytes).

Returns:

  • (Integer)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the DB instance.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_typeString

The Timestream for InfluxDB instance type to run InfluxDB on.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#db_storage_typeString

The storage type for your DB instance.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_typeString

Single-Instance or with a MultiAZ Standby for High availability.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#endpointString

The endpoint used to connect to InfluxDB. The default InfluxDB port is 8086.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The service-generated unique identifier of the DB instance.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

This customer-supplied name uniquely identifies the DB instance when interacting with the Amazon Timestream for InfluxDB API and CLI commands.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#network_typeString

Specifies whether the networkType of the Timestream for InfluxDB instance is IPV4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port number on which InfluxDB accepts connections.

Returns:

  • (Integer)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the DB instance.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147

class DbInstanceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end