Class: Aws::TimestreamInfluxDB::Types::DeleteDbBackupOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

The allocated storage of the resource at the time of backup, in GiB.

Returns:

  • (Integer)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the deleted backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_configurationTypes::ClusterConfiguration

The cluster configuration of the resource at the time of backup.



1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time when the backup was created.

Returns:

  • (Time)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_typeString

The DB instance type of the resource at the time of backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#db_parameter_group_idString

The identifier of the DB parameter group associated with the backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#db_resource_idString

The identifier of the DB resource that the backup was created from.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#db_storage_typeString

The storage type of the resource at the time of backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_typeString

The deployment type of the resource that the backup was created from.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#engine_typeString

The engine type of the resource that the backup was created from.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#expires_afterString

The date after which the backup was set to be automatically deleted.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#failover_modeString

The failover mode of the resource at the time of backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Service-generated unique identifier of the deleted backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#influx_auth_parameters_secret_arnString

The ARN of the Secrets Manager secret containing the InfluxDB auth parameters.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Web Services KMS key ARN used for encryption of the resource at the time of backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_configurationTypes::LogDeliveryConfiguration

The log delivery configuration of the resource at the time of backup.



1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_scheduleTypes::MaintenanceSchedule

The maintenance schedule of the resource at the time of backup.



1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The customer-provided name of the deleted backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#network_typeString

The network type of the resource at the time of backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port number of the resource at the time of backup.

Returns:

  • (Integer)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#publicly_accessibleBoolean

Indicates whether the resource was publicly accessible at the time of backup.

Returns:

  • (Boolean)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of backup.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_security_group_idsArray<String>

The VPC security group IDs associated with the resource at the time of backup.

Returns:

  • (Array<String>)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_subnet_idsArray<String>

The VPC subnet IDs associated with the resource at the time of backup.

Returns:

  • (Array<String>)


1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1313

class DeleteDbBackupOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :created_at,
  :expires_after,
  :db_resource_id,
  :type,
  :engine_type,
  :deployment_type,
  :kms_key_id,
  :cluster_configuration,
  :db_parameter_group_id,
  :db_instance_type,
  :log_delivery_configuration,
  :failover_mode,
  :db_storage_type,
  :allocated_storage,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :port,
  :network_type,
  :influx_auth_parameters_secret_arn,
  :maintenance_schedule)
  SENSITIVE = []
  include Aws::Structure
end