Class: Aws::TimestreamInfluxDB::Types::DeleteDbClusterInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_cluster_idString

Service-generated unique identifier of the DB cluster.

Returns:

  • (String)


1355
1356
1357
1358
1359
1360
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1355

class DeleteDbClusterInput < Struct.new(
  :db_cluster_id,
  :retain_automated_backups)
  SENSITIVE = []
  include Aws::Structure
end

#retain_automated_backupsBoolean

Specifies whether to retain automated backups after the DB cluster is deleted. If set to true, automated backups are not deleted and can be restored later.

Returns:

  • (Boolean)


1355
1356
1357
1358
1359
1360
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1355

class DeleteDbClusterInput < Struct.new(
  :db_cluster_id,
  :retain_automated_backups)
  SENSITIVE = []
  include Aws::Structure
end