Class: Aws::TimestreamInfluxDB::Types::DeleteDbInstanceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

The id of the DB instance.

Returns:

  • (String)


1386
1387
1388
1389
1390
1391
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1386

class DeleteDbInstanceInput < Struct.new(
  :identifier,
  :retain_automated_backups)
  SENSITIVE = []
  include Aws::Structure
end

#retain_automated_backupsBoolean

Specifies whether to retain automated backups after the DB instance is deleted. If set to true, automated backups are not deleted and can be restored later.

Returns:

  • (Boolean)


1386
1387
1388
1389
1390
1391
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1386

class DeleteDbInstanceInput < Struct.new(
  :identifier,
  :retain_automated_backups)
  SENSITIVE = []
  include Aws::Structure
end