Class: Aws::TimestreamInfluxDB::Types::DeleteDbInstanceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::DeleteDbInstanceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The amount of storage allocated for your DB storage type (in gibibytes).
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the DB instance.
-
#availability_zone ⇒ String
The Availability Zone in which the DB instance resides.
-
#db_instance_type ⇒ String
The Timestream for InfluxDB instance type that InfluxDB runs on.
-
#db_parameter_group_identifier ⇒ String
The id of the DB parameter group assigned to your DB instance.
-
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type that InfluxDB stores data on.
-
#deployment_type ⇒ String
Specifies whether the Timestream for InfluxDB is deployed as Single-AZ or with a MultiAZ Standby for High availability.
-
#endpoint ⇒ String
The endpoint used to connect to InfluxDB.
-
#id ⇒ String
A service-generated unique identifier.
-
#influx_auth_parameters_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret containing the initial InfluxDB authorization parameters.
-
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to send to specified S3 bucket.
-
#name ⇒ String
The customer-supplied name that uniquely identifies the DB instance when interacting with the Amazon Timestream for InfluxDB API and CLI commands.
-
#network_type ⇒ String
Specifies whether the networkType of the Timestream for InfluxDB instance is IPV4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
-
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
-
#publicly_accessible ⇒ Boolean
Indicates if the DB instance has a public IP to facilitate access.
-
#secondary_availability_zone ⇒ String
The Availability Zone in which the standby instance is located when deploying with a MultiAZ standby instance.
-
#status ⇒ String
The status of the DB instance.
-
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security group IDs associated with the DB instance.
-
#vpc_subnet_ids ⇒ Array<String>
A list of VPC subnet IDs associated with the DB instance.
Instance Attribute Details
#allocated_storage ⇒ Integer
The amount of storage allocated for your DB storage type (in gibibytes).
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the DB instance.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone in which the DB instance resides.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#db_instance_type ⇒ String
The Timestream for InfluxDB instance type that InfluxDB runs on.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#db_parameter_group_identifier ⇒ String
The id of the DB parameter group assigned to your DB instance.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type that InfluxDB stores data on.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#deployment_type ⇒ String
Specifies whether the Timestream for InfluxDB is deployed as Single-AZ or with a MultiAZ Standby for High availability.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The endpoint used to connect to InfluxDB. The default InfluxDB port is 8086.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A service-generated unique identifier.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#influx_auth_parameters_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret containing the initial InfluxDB authorization parameters. The secret value is a JSON formatted key-value pair holding InfluxDB authorization values: organization, bucket, username, and password.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to send to specified S3 bucket.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The customer-supplied name that uniquely identifies the DB instance when interacting with the Amazon Timestream for InfluxDB API and CLI commands.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
Specifies whether the networkType of the Timestream for InfluxDB instance is IPV4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#publicly_accessible ⇒ Boolean
Indicates if the DB instance has a public IP to facilitate access.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#secondary_availability_zone ⇒ String
The Availability Zone in which the standby instance is located when deploying with a MultiAZ standby instance.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the DB instance.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security group IDs associated with the DB instance.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |
#vpc_subnet_ids ⇒ Array<String>
A list of VPC subnet IDs associated with the DB instance.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 571 class DeleteDbInstanceOutput < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type, :vpc_subnet_ids, :publicly_accessible, :vpc_security_group_ids, :db_parameter_group_identifier, :availability_zone, :secondary_availability_zone, :log_delivery_configuration, :influx_auth_parameters_secret_arn) SENSITIVE = [] include Aws::Structure end |