Class: Aws::TimestreamInfluxDB::Types::GetDbBackupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::GetDbBackupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
The identifier of the backup to retrieve information for.
Instance Attribute Details
#identifier ⇒ String
The identifier of the backup to retrieve information for.
1577 1578 1579 1580 1581 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1577 class GetDbBackupInput < Struct.new( :identifier) SENSITIVE = [] include Aws::Structure end |