Class: Aws::TimestreamInfluxDB::Types::RestoreFromDbBackupInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_backup_configurationsArray<Types::DbBackupConfiguration>

A list of backup configurations to apply to the restored resource.

Returns:



3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_backup_idString

The identifier of the backup to restore from.

Returns:

  • (String)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_typeString

Specifies the deployment type of the restored resource. Valid values are SINGLE_AZ, WITH_MULTIAZ_STANDBY, and MULTI_NODE_READ_REPLICAS.

Returns:

  • (String)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Web Services KMS key identifier to use for encryption of the restored resource. Can be a key ID, key ARN, alias name, or alias ARN.

Returns:

  • (String)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_configurationTypes::LogDeliveryConfiguration

Configuration for sending InfluxDB engine logs to the specified S3 bucket for the restored resource.



3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_scheduleTypes::MaintenanceSchedule

The maintenance schedule for the restored resource.



3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the new resource to create from the restore. If restoring to an existing resource, the name must match the existing resource name.

Returns:

  • (String)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_typeString

Specifies the network type of the restored resource. Valid values are IPV4 and DUAL.

Returns:

  • (String)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port number on which the restored InfluxDB resource accepts connections.

Returns:

  • (Integer)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#publicly_accessibleBoolean

Specifies whether the restored resource is publicly accessible.

Returns:

  • (Boolean)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#restore_modeString

Specifies whether to restore to a new resource or replace the existing resource. Valid values are NEW_RESOURCE (default) and REPLACE_EXISTING.

Returns:

  • (String)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#restore_to_timeTime

The point in time to restore to, for continuous backups. Must be within the backup's retention window.

Returns:

  • (Time)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of key-value pairs to associate with the restored resource.

Returns:

  • (Hash<String,String>)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_security_group_idsArray<String>

A list of VPC security group IDs for the restored resource. If not specified, the restored resource uses the same security groups as the backup.

Returns:

  • (Array<String>)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_subnet_idsArray<String>

A list of VPC subnet IDs for the restored resource. If not specified, the restored resource uses the same subnets as the backup.

Returns:

  • (Array<String>)


3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3802

class RestoreFromDbBackupInput < Struct.new(
  :name,
  :db_backup_id,
  :restore_to_time,
  :restore_mode,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :publicly_accessible,
  :log_delivery_configuration,
  :maintenance_schedule,
  :tags,
  :port,
  :network_type,
  :deployment_type,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end