Class: Aws::TimestreamInfluxDB::Types::UpdateDbClusterInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_backup_configurationsArray<Types::DbBackupConfiguration>

A list of backup configurations to update for the DB cluster.

Returns:



3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3963

class UpdateDbClusterInput < Struct.new(
  :db_cluster_id,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :failover_mode,
  :maintenance_schedule,
  :db_backup_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_idString

Service-generated unique identifier of the DB cluster to update.

Returns:

  • (String)


3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3963

class UpdateDbClusterInput < Struct.new(
  :db_cluster_id,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :failover_mode,
  :maintenance_schedule,
  :db_backup_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_typeString

Update the DB cluster to use the specified DB instance Type.

Returns:

  • (String)


3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3963

class UpdateDbClusterInput < Struct.new(
  :db_cluster_id,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :failover_mode,
  :maintenance_schedule,
  :db_backup_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#db_parameter_group_identifierString

Update the DB cluster to use the specified DB parameter group.

Returns:

  • (String)


3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3963

class UpdateDbClusterInput < Struct.new(
  :db_cluster_id,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :failover_mode,
  :maintenance_schedule,
  :db_backup_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#failover_modeString

Update the DB cluster's failover behavior.

Returns:

  • (String)


3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3963

class UpdateDbClusterInput < Struct.new(
  :db_cluster_id,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :failover_mode,
  :maintenance_schedule,
  :db_backup_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_configurationTypes::LogDeliveryConfiguration

The log delivery configuration to apply to the DB cluster.



3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3963

class UpdateDbClusterInput < Struct.new(
  :db_cluster_id,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :failover_mode,
  :maintenance_schedule,
  :db_backup_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_scheduleTypes::MaintenanceSchedule

Specifies the maintenance schedule for the DB cluster, including the preferred maintenance window and timezone.



3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3963

class UpdateDbClusterInput < Struct.new(
  :db_cluster_id,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :failover_mode,
  :maintenance_schedule,
  :db_backup_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

Update the DB cluster to use the specified port.

Returns:

  • (Integer)


3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3963

class UpdateDbClusterInput < Struct.new(
  :db_cluster_id,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :failover_mode,
  :maintenance_schedule,
  :db_backup_configurations)
  SENSITIVE = []
  include Aws::Structure
end