Class: Aws::TimestreamInfluxDB::Types::UpdateDbInstanceOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

The amount of storage allocated for your DB storage type (in gibibytes).

Returns:

  • (Integer)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the DB instance.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone in which the DB instance resides.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_idString

Specifies the DbCluster to which this DbInstance belongs to.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_typeString

The Timestream for InfluxDB instance type that InfluxDB runs on.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#db_parameter_group_identifierString

The id of the DB parameter group assigned to your DB instance.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#db_storage_typeString

The Timestream for InfluxDB DB storage type that InfluxDB stores data on.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_typeString

Specifies whether the Timestream for InfluxDB is deployed as Single-AZ or with a MultiAZ Standby for High availability.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#endpointString

The endpoint used to connect to InfluxDB. The default InfluxDB port is 8086.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A service-generated unique identifier.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#influx_auth_parameters_secret_arnString

The Amazon Resource Name (ARN) of the Secrets Manager secret containing the initial InfluxDB authorization parameters. The secret value is a JSON formatted key-value pair holding InfluxDB authorization values: organization, bucket, username, and password.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#instance_modeString

Specifies the DbInstance's role in the cluster.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#instance_modesArray<String>

Specifies the DbInstance's roles in the cluster.

Returns:

  • (Array<String>)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_maintenance_timeTime

The timestamp of the last completed maintenance operation on the DB instance.

Returns:

  • (Time)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_configurationTypes::LogDeliveryConfiguration

Configuration for sending InfluxDB engine logs to send to specified S3 bucket.



3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_scheduleTypes::MaintenanceSchedule

The maintenance schedule for the DB instance.



3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

This customer-supplied name uniquely identifies the DB instance when interacting with the Amazon Timestream for InfluxDB API and CLI commands.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#network_typeString

Specifies whether the networkType of the Timestream for InfluxDB instance is IPV4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#next_maintenance_timeTime

The timestamp of the next scheduled maintenance operation on the DB instance.

Returns:

  • (Time)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port number on which InfluxDB accepts connections.

Returns:

  • (Integer)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#publicly_accessibleBoolean

Indicates if the DB instance has a public IP to facilitate access.

Returns:

  • (Boolean)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_availability_zoneString

The Availability Zone in which the standby instance is located when deploying with a MultiAZ standby instance.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the DB instance.

Returns:

  • (String)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_security_group_idsArray<String>

A list of VPC security group IDs associated with the DB instance.

Returns:

  • (Array<String>)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_subnet_idsArray<String>

A list of VPC subnet IDs associated with the DB instance.

Returns:

  • (Array<String>)


3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3294

class UpdateDbInstanceOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :port,
  :network_type,
  :db_instance_type,
  :db_storage_type,
  :allocated_storage,
  :deployment_type,
  :vpc_subnet_ids,
  :publicly_accessible,
  :vpc_security_group_ids,
  :db_parameter_group_identifier,
  :availability_zone,
  :secondary_availability_zone,
  :log_delivery_configuration,
  :influx_auth_parameters_secret_arn,
  :db_cluster_id,
  :instance_mode,
  :instance_modes,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time)
  SENSITIVE = []
  include Aws::Structure
end