Class: Aws::TimestreamInfluxDB::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::TimestreamInfluxDB::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/client.rb
Overview
An API client for TimestreamInfluxDB. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::TimestreamInfluxDB::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_db_cluster(params = {}) ⇒ Types::CreateDbClusterOutput
Creates a new Timestream for InfluxDB cluster.
-
#create_db_instance(params = {}) ⇒ Types::CreateDbInstanceOutput
Creates a new Timestream for InfluxDB DB instance.
-
#create_db_parameter_group(params = {}) ⇒ Types::CreateDbParameterGroupOutput
Creates a new Timestream for InfluxDB DB parameter group to associate with DB instances.
-
#delete_db_cluster(params = {}) ⇒ Types::DeleteDbClusterOutput
Deletes a Timestream for InfluxDB cluster.
-
#delete_db_instance(params = {}) ⇒ Types::DeleteDbInstanceOutput
Deletes a Timestream for InfluxDB DB instance.
-
#get_db_cluster(params = {}) ⇒ Types::GetDbClusterOutput
Retrieves information about a Timestream for InfluxDB cluster.
-
#get_db_instance(params = {}) ⇒ Types::GetDbInstanceOutput
Returns a Timestream for InfluxDB DB instance.
-
#get_db_parameter_group(params = {}) ⇒ Types::GetDbParameterGroupOutput
Returns a Timestream for InfluxDB DB parameter group.
-
#list_db_clusters(params = {}) ⇒ Types::ListDbClustersOutput
Returns a list of Timestream for InfluxDB DB clusters.
-
#list_db_instances(params = {}) ⇒ Types::ListDbInstancesOutput
Returns a list of Timestream for InfluxDB DB instances.
-
#list_db_instances_for_cluster(params = {}) ⇒ Types::ListDbInstancesForClusterOutput
Returns a list of Timestream for InfluxDB clusters.
-
#list_db_parameter_groups(params = {}) ⇒ Types::ListDbParameterGroupsOutput
Returns a list of Timestream for InfluxDB DB parameter groups.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of tags applied to the resource.
-
#tag_resource(params = {}) ⇒ Struct
Tags are composed of a Key/Value pairs.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tag from the specified resource.
-
#update_db_cluster(params = {}) ⇒ Types::UpdateDbClusterOutput
Updates a Timestream for InfluxDB cluster.
-
#update_db_instance(params = {}) ⇒ Types::UpdateDbInstanceOutput
Updates a Timestream for InfluxDB DB instance.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1772 1773 1774 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1772 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1775 1776 1777 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1775 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1745 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::TimestreamInfluxDB') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-timestreaminfluxdb' context[:gem_version] = '1.25.0' Seahorse::Client::Request.new(handlers, context) end |
#create_db_cluster(params = {}) ⇒ Types::CreateDbClusterOutput
Creates a new Timestream for InfluxDB cluster.
624 625 626 627 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 624 def create_db_cluster(params = {}, = {}) req = build_request(:create_db_cluster, params) req.send_request() end |
#create_db_instance(params = {}) ⇒ Types::CreateDbInstanceOutput
Creates a new Timestream for InfluxDB DB instance.
809 810 811 812 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 809 def create_db_instance(params = {}, = {}) req = build_request(:create_db_instance, params) req.send_request() end |
#create_db_parameter_group(params = {}) ⇒ Types::CreateDbParameterGroupOutput
Creates a new Timestream for InfluxDB DB parameter group to associate with DB instances.
963 964 965 966 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 963 def create_db_parameter_group(params = {}, = {}) req = build_request(:create_db_parameter_group, params) req.send_request() end |
#delete_db_cluster(params = {}) ⇒ Types::DeleteDbClusterOutput
Deletes a Timestream for InfluxDB cluster.
991 992 993 994 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 991 def delete_db_cluster(params = {}, = {}) req = build_request(:delete_db_cluster, params) req.send_request() end |
#delete_db_instance(params = {}) ⇒ Types::DeleteDbInstanceOutput
Deletes a Timestream for InfluxDB DB instance.
1062 1063 1064 1065 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1062 def delete_db_instance(params = {}, = {}) req = build_request(:delete_db_instance, params) req.send_request() end |
#get_db_cluster(params = {}) ⇒ Types::GetDbClusterOutput
Retrieves information about a Timestream for InfluxDB cluster.
1129 1130 1131 1132 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1129 def get_db_cluster(params = {}, = {}) req = build_request(:get_db_cluster, params) req.send_request() end |
#get_db_instance(params = {}) ⇒ Types::GetDbInstanceOutput
Returns a Timestream for InfluxDB DB instance.
1200 1201 1202 1203 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1200 def get_db_instance(params = {}, = {}) req = build_request(:get_db_instance, params) req.send_request() end |
#get_db_parameter_group(params = {}) ⇒ Types::GetDbParameterGroupOutput
Returns a Timestream for InfluxDB DB parameter group.
1277 1278 1279 1280 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1277 def get_db_parameter_group(params = {}, = {}) req = build_request(:get_db_parameter_group, params) req.send_request() end |
#list_db_clusters(params = {}) ⇒ Types::ListDbClustersOutput
Returns a list of Timestream for InfluxDB DB clusters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1329 1330 1331 1332 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1329 def list_db_clusters(params = {}, = {}) req = build_request(:list_db_clusters, params) req.send_request() end |
#list_db_instances(params = {}) ⇒ Types::ListDbInstancesOutput
Returns a list of Timestream for InfluxDB DB instances.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1380 1381 1382 1383 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1380 def list_db_instances(params = {}, = {}) req = build_request(:list_db_instances, params) req.send_request() end |
#list_db_instances_for_cluster(params = {}) ⇒ Types::ListDbInstancesForClusterOutput
Returns a list of Timestream for InfluxDB clusters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1436 1437 1438 1439 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1436 def list_db_instances_for_cluster(params = {}, = {}) req = build_request(:list_db_instances_for_cluster, params) req.send_request() end |
#list_db_parameter_groups(params = {}) ⇒ Types::ListDbParameterGroupsOutput
Returns a list of Timestream for InfluxDB DB parameter groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1480 1481 1482 1483 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1480 def list_db_parameter_groups(params = {}, = {}) req = build_request(:list_db_parameter_groups, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of tags applied to the resource.
1509 1510 1511 1512 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1509 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags are composed of a Key/Value pairs. You can use tags to categorize and track your Timestream for InfluxDB resources.
1538 1539 1540 1541 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1538 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the tag from the specified resource.
1564 1565 1566 1567 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1564 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_db_cluster(params = {}) ⇒ Types::UpdateDbClusterOutput
Updates a Timestream for InfluxDB cluster.
1617 1618 1619 1620 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1617 def update_db_cluster(params = {}, = {}) req = build_request(:update_db_cluster, params) req.send_request() end |
#update_db_instance(params = {}) ⇒ Types::UpdateDbInstanceOutput
Updates a Timestream for InfluxDB DB instance.
1736 1737 1738 1739 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1736 def update_db_instance(params = {}, = {}) req = build_request(:update_db_instance, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1765 1766 1767 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1765 def waiter_names [] end |