Class: Aws::TimestreamInfluxDB::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::TimestreamInfluxDB::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/client.rb
Overview
An API client for TimestreamInfluxDB. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::TimestreamInfluxDB::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_db_instance(params = {}) ⇒ Types::CreateDbInstanceOutput
Creates a new Timestream for InfluxDB DB instance.
-
#create_db_parameter_group(params = {}) ⇒ Types::CreateDbParameterGroupOutput
Creates a new Timestream for InfluxDB DB parameter group to associate with DB instances.
-
#delete_db_instance(params = {}) ⇒ Types::DeleteDbInstanceOutput
Deletes a Timestream for InfluxDB DB instance.
-
#get_db_instance(params = {}) ⇒ Types::GetDbInstanceOutput
Returns a Timestream for InfluxDB DB instance.
-
#get_db_parameter_group(params = {}) ⇒ Types::GetDbParameterGroupOutput
Returns a Timestream for InfluxDB DB parameter group.
-
#list_db_instances(params = {}) ⇒ Types::ListDbInstancesOutput
Returns a list of Timestream for InfluxDB DB instances.
-
#list_db_parameter_groups(params = {}) ⇒ Types::ListDbParameterGroupsOutput
Returns a list of Timestream for InfluxDB DB parameter groups.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of tags applied to the resource.
-
#tag_resource(params = {}) ⇒ Struct
Tags are composed of a Key/Value pairs.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tag from the specified resource.
-
#update_db_instance(params = {}) ⇒ Types::UpdateDbInstanceOutput
Updates a Timestream for InfluxDB DB instance.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
441 442 443 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 441 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1139 1140 1141 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1139 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1142 1143 1144 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1142 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1112 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::TimestreamInfluxDB') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-timestreaminfluxdb' context[:gem_version] = '1.7.0' Seahorse::Client::Request.new(handlers, context) end |
#create_db_instance(params = {}) ⇒ Types::CreateDbInstanceOutput
Creates a new Timestream for InfluxDB DB instance.
602 603 604 605 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 602 def create_db_instance(params = {}, = {}) req = build_request(:create_db_instance, params) req.send_request() end |
#create_db_parameter_group(params = {}) ⇒ Types::CreateDbParameterGroupOutput
Creates a new Timestream for InfluxDB DB parameter group to associate with DB instances.
670 671 672 673 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 670 def create_db_parameter_group(params = {}, = {}) req = build_request(:create_db_parameter_group, params) req.send_request() end |
#delete_db_instance(params = {}) ⇒ Types::DeleteDbInstanceOutput
Deletes a Timestream for InfluxDB DB instance.
733 734 735 736 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 733 def delete_db_instance(params = {}, = {}) req = build_request(:delete_db_instance, params) req.send_request() end |
#get_db_instance(params = {}) ⇒ Types::GetDbInstanceOutput
Returns a Timestream for InfluxDB DB instance.
796 797 798 799 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 796 def get_db_instance(params = {}, = {}) req = build_request(:get_db_instance, params) req.send_request() end |
#get_db_parameter_group(params = {}) ⇒ Types::GetDbParameterGroupOutput
Returns a Timestream for InfluxDB DB parameter group.
838 839 840 841 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 838 def get_db_parameter_group(params = {}, = {}) req = build_request(:get_db_parameter_group, params) req.send_request() end |
#list_db_instances(params = {}) ⇒ Types::ListDbInstancesOutput
Returns a list of Timestream for InfluxDB DB instances.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
887 888 889 890 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 887 def list_db_instances(params = {}, = {}) req = build_request(:list_db_instances, params) req.send_request() end |
#list_db_parameter_groups(params = {}) ⇒ Types::ListDbParameterGroupsOutput
Returns a list of Timestream for InfluxDB DB parameter groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
931 932 933 934 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 931 def list_db_parameter_groups(params = {}, = {}) req = build_request(:list_db_parameter_groups, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of tags applied to the resource.
960 961 962 963 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 960 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags are composed of a Key/Value pairs. You can use tags to categorize and track your Timestream for InfluxDB resources.
989 990 991 992 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 989 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the tag from the specified resource.
1015 1016 1017 1018 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1015 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_db_instance(params = {}) ⇒ Types::UpdateDbInstanceOutput
Updates a Timestream for InfluxDB DB instance.
1103 1104 1105 1106 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1103 def update_db_instance(params = {}, = {}) req = build_request(:update_db_instance, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1132 1133 1134 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1132 def waiter_names [] end |