Class: Aws::TimestreamInfluxDB::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::TimestreamInfluxDB::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/client.rb
Overview
An API client for TimestreamInfluxDB. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::TimestreamInfluxDB::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_db_instance(params = {}) ⇒ Types::CreateDbInstanceOutput
Creates a new Timestream for InfluxDB DB instance.
-
#create_db_parameter_group(params = {}) ⇒ Types::CreateDbParameterGroupOutput
Creates a new Timestream for InfluxDB DB parameter group to associate with DB instances.
-
#delete_db_instance(params = {}) ⇒ Types::DeleteDbInstanceOutput
Deletes a Timestream for InfluxDB DB instance.
-
#get_db_instance(params = {}) ⇒ Types::GetDbInstanceOutput
Returns a Timestream for InfluxDB DB instance.
-
#get_db_parameter_group(params = {}) ⇒ Types::GetDbParameterGroupOutput
Returns a Timestream for InfluxDB DB parameter group.
-
#list_db_instances(params = {}) ⇒ Types::ListDbInstancesOutput
Returns a list of Timestream for InfluxDB DB instances.
-
#list_db_parameter_groups(params = {}) ⇒ Types::ListDbParameterGroupsOutput
Returns a list of Timestream for InfluxDB DB parameter groups.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of tags applied to the resource.
-
#tag_resource(params = {}) ⇒ Struct
Tags are composed of a Key/Value pairs.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tag from the specified resource.
-
#update_db_instance(params = {}) ⇒ Types::UpdateDbInstanceOutput
Updates a Timestream for InfluxDB DB instance.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
395 396 397 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 395 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1079 1080 1081 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1079 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1082 1083 1084 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1082 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1057 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-timestreaminfluxdb' context[:gem_version] = '1.0.0' Seahorse::Client::Request.new(handlers, context) end |
#create_db_instance(params = {}) ⇒ Types::CreateDbInstanceOutput
Creates a new Timestream for InfluxDB DB instance.
556 557 558 559 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 556 def create_db_instance(params = {}, = {}) req = build_request(:create_db_instance, params) req.send_request() end |
#create_db_parameter_group(params = {}) ⇒ Types::CreateDbParameterGroupOutput
Creates a new Timestream for InfluxDB DB parameter group to associate with DB instances.
624 625 626 627 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 624 def create_db_parameter_group(params = {}, = {}) req = build_request(:create_db_parameter_group, params) req.send_request() end |
#delete_db_instance(params = {}) ⇒ Types::DeleteDbInstanceOutput
Deletes a Timestream for InfluxDB DB instance.
687 688 689 690 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 687 def delete_db_instance(params = {}, = {}) req = build_request(:delete_db_instance, params) req.send_request() end |
#get_db_instance(params = {}) ⇒ Types::GetDbInstanceOutput
Returns a Timestream for InfluxDB DB instance.
750 751 752 753 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 750 def get_db_instance(params = {}, = {}) req = build_request(:get_db_instance, params) req.send_request() end |
#get_db_parameter_group(params = {}) ⇒ Types::GetDbParameterGroupOutput
Returns a Timestream for InfluxDB DB parameter group.
792 793 794 795 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 792 def get_db_parameter_group(params = {}, = {}) req = build_request(:get_db_parameter_group, params) req.send_request() end |
#list_db_instances(params = {}) ⇒ Types::ListDbInstancesOutput
Returns a list of Timestream for InfluxDB DB instances.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
841 842 843 844 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 841 def list_db_instances(params = {}, = {}) req = build_request(:list_db_instances, params) req.send_request() end |
#list_db_parameter_groups(params = {}) ⇒ Types::ListDbParameterGroupsOutput
Returns a list of Timestream for InfluxDB DB parameter groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
885 886 887 888 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 885 def list_db_parameter_groups(params = {}, = {}) req = build_request(:list_db_parameter_groups, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of tags applied to the resource.
914 915 916 917 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 914 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags are composed of a Key/Value pairs. You can use tags to categorize and track your Timestream for InfluxDB resources.
943 944 945 946 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 943 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the tag from the specified resource.
969 970 971 972 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 969 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_db_instance(params = {}) ⇒ Types::UpdateDbInstanceOutput
Updates a Timestream for InfluxDB DB instance.
1048 1049 1050 1051 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1048 def update_db_instance(params = {}, = {}) req = build_request(:update_db_instance, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1072 1073 1074 |
# File 'lib/aws-sdk-timestreaminfluxdb/client.rb', line 1072 def waiter_names [] end |