Class: Aws::TimestreamInfluxDB::Types::DbBackupConfigurationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::DbBackupConfigurationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Contains the configuration and status for an automated backup schedule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_schedule ⇒ String
The custom cron schedule expression for the backup, if applicable.
-
#enabled ⇒ Boolean
Indicates whether this backup configuration is enabled.
-
#next_automated_backup_time ⇒ Time
The next scheduled time for an automated backup to be taken.
-
#retention_days ⇒ Integer
The number of days automated backups are retained.
-
#type ⇒ String
The type of automated backup schedule.
Instance Attribute Details
#custom_schedule ⇒ String
The custom cron schedule expression for the backup, if applicable.
856 857 858 859 860 861 862 863 864 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 856 class DbBackupConfigurationOutput < Struct.new( :type, :retention_days, :enabled, :custom_schedule, :next_automated_backup_time) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Indicates whether this backup configuration is enabled.
856 857 858 859 860 861 862 863 864 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 856 class DbBackupConfigurationOutput < Struct.new( :type, :retention_days, :enabled, :custom_schedule, :next_automated_backup_time) SENSITIVE = [] include Aws::Structure end |
#next_automated_backup_time ⇒ Time
The next scheduled time for an automated backup to be taken.
856 857 858 859 860 861 862 863 864 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 856 class DbBackupConfigurationOutput < Struct.new( :type, :retention_days, :enabled, :custom_schedule, :next_automated_backup_time) SENSITIVE = [] include Aws::Structure end |
#retention_days ⇒ Integer
The number of days automated backups are retained.
856 857 858 859 860 861 862 863 864 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 856 class DbBackupConfigurationOutput < Struct.new( :type, :retention_days, :enabled, :custom_schedule, :next_automated_backup_time) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of automated backup schedule.
856 857 858 859 860 861 862 863 864 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 856 class DbBackupConfigurationOutput < Struct.new( :type, :retention_days, :enabled, :custom_schedule, :next_automated_backup_time) SENSITIVE = [] include Aws::Structure end |