Class: Aws::TimestreamInfluxDB::Types::DbBackupSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::DbBackupSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Contains a summary of a Timestream for InfluxDB backup.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the backup.
-
#created_at ⇒ Time
The time when the backup was created.
-
#db_resource_id ⇒ String
The identifier of the DB resource that the backup was created from.
-
#deployment_type ⇒ String
The deployment type of the resource that the backup was created from.
-
#engine_type ⇒ String
The engine type of the resource that the backup was created from.
-
#expires_after ⇒ String
The date after which the backup will be automatically deleted.
-
#id ⇒ String
Service-generated unique identifier of the backup.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key ARN used for encryption of the resource at the time of backup.
-
#name ⇒ String
The customer-provided name of the backup.
-
#status ⇒ String
The status of the backup.
-
#type ⇒ String
The type of backup.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the backup.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time when the backup was created.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#db_resource_id ⇒ String
The identifier of the DB resource that the backup was created from.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#deployment_type ⇒ String
The deployment type of the resource that the backup was created from.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#engine_type ⇒ String
The engine type of the resource that the backup was created from.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#expires_after ⇒ String
The date after which the backup will be automatically deleted.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Service-generated unique identifier of the backup.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key ARN used for encryption of the resource at the time of backup.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The customer-provided name of the backup.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the backup. Valid values are IN_PROGRESS, COMPLETED, FAILED, DELETING, and DELETED.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of backup. Valid values are HOURLY, DAILY, WEEKLY, MONTHLY, CUSTOM_SCHEDULE, ON_DEMAND, and CONTINUOUS.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 918 class DbBackupSummary < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |