Class: Aws::TimestreamInfluxDB::Types::DbInstanceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::DbInstanceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Contains a summary of a DB instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The amount of storage to allocate for your DbStorageType in GiB (gibibytes).
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the DB instance.
-
#db_instance_type ⇒ String
The Timestream for InfluxDB instance type to run InfluxDB on.
-
#db_storage_type ⇒ String
The storage type for your DB instance.
-
#deployment_type ⇒ String
Single-Instance or with a MultiAZ Standby for High availability.
-
#endpoint ⇒ String
The endpoint used to connect to InfluxDB.
-
#id ⇒ String
The service-generated unique identifier of the DB instance.
-
#name ⇒ String
This customer-supplied name uniquely identifies the DB instance when interacting with the Amazon Timestream for InfluxDB API and CLI commands.
-
#network_type ⇒ String
Specifies whether the networkType of the Timestream for InfluxDB instance is IPV4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
-
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
-
#status ⇒ String
The status of the DB instance.
Instance Attribute Details
#allocated_storage ⇒ Integer
The amount of storage to allocate for your DbStorageType in GiB (gibibytes).
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the DB instance.
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#db_instance_type ⇒ String
The Timestream for InfluxDB instance type to run InfluxDB on.
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#db_storage_type ⇒ String
The storage type for your DB instance.
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#deployment_type ⇒ String
Single-Instance or with a MultiAZ Standby for High availability.
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The endpoint used to connect to InfluxDB. The default InfluxDB port is 8086.
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The service-generated unique identifier of the DB instance.
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
This customer-supplied name uniquely identifies the DB instance when interacting with the Amazon Timestream for InfluxDB API and CLI commands.
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
Specifies whether the networkType of the Timestream for InfluxDB instance is IPV4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the DB instance.
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1147 class DbInstanceSummary < Struct.new( :id, :name, :arn, :status, :endpoint, :port, :network_type, :db_instance_type, :db_storage_type, :allocated_storage, :deployment_type) SENSITIVE = [] include Aws::Structure end |