Class: Aws::TimestreamInfluxDB::Types::GetDbBackupOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::GetDbBackupOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The allocated storage of the resource at the time of backup, in GiB.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the backup.
-
#cluster_configuration ⇒ Types::ClusterConfiguration
The cluster configuration of the resource at the time of backup.
-
#created_at ⇒ Time
The time when the backup was created.
-
#db_instance_type ⇒ String
The DB instance type of the resource at the time of backup.
-
#db_parameter_group_id ⇒ String
The identifier of the DB parameter group associated with the backup.
-
#db_resource_id ⇒ String
The identifier of the DB resource that the backup was created from.
-
#db_storage_type ⇒ String
The storage type of the resource at the time of backup.
-
#deployment_type ⇒ String
The deployment type of the resource that the backup was created from.
-
#engine_type ⇒ String
The engine type of the resource that the backup was created from.
-
#expires_after ⇒ String
The date after which the backup will be automatically deleted.
-
#failover_mode ⇒ String
The failover mode of the resource at the time of backup.
-
#id ⇒ String
Service-generated unique identifier of the backup.
-
#influx_auth_parameters_secret_arn ⇒ String
The ARN of the Secrets Manager secret containing the InfluxDB auth parameters.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key ARN used for encryption of the resource at the time of backup.
-
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
The log delivery configuration of the resource at the time of backup.
-
#maintenance_schedule ⇒ Types::MaintenanceSchedule
The maintenance schedule of the resource at the time of backup.
-
#name ⇒ String
The customer-provided name of the backup.
-
#network_type ⇒ String
The network type of the resource at the time of backup.
-
#port ⇒ Integer
The port number of the resource at the time of backup.
-
#publicly_accessible ⇒ Boolean
Indicates whether the resource was publicly accessible at the time of backup.
-
#status ⇒ String
The current status of the backup.
-
#type ⇒ String
The type of backup.
-
#vpc_security_group_ids ⇒ Array<String>
The VPC security group IDs associated with the resource at the time of backup.
-
#vpc_subnet_ids ⇒ Array<String>
The VPC subnet IDs associated with the resource at the time of backup.
Instance Attribute Details
#allocated_storage ⇒ Integer
The allocated storage of the resource at the time of backup, in GiB.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#cluster_configuration ⇒ Types::ClusterConfiguration
The cluster configuration of the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time when the backup was created.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#db_instance_type ⇒ String
The DB instance type of the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#db_parameter_group_id ⇒ String
The identifier of the DB parameter group associated with the backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#db_resource_id ⇒ String
The identifier of the DB resource that the backup was created from.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#db_storage_type ⇒ String
The storage type of the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#deployment_type ⇒ String
The deployment type of the resource that the backup was created from.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#engine_type ⇒ String
The engine type of the resource that the backup was created from.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#expires_after ⇒ String
The date after which the backup will be automatically deleted.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#failover_mode ⇒ String
The failover mode of the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Service-generated unique identifier of the backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#influx_auth_parameters_secret_arn ⇒ String
The ARN of the Secrets Manager secret containing the InfluxDB auth parameters.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key ARN used for encryption of the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
The log delivery configuration of the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#maintenance_schedule ⇒ Types::MaintenanceSchedule
The maintenance schedule of the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The customer-provided name of the backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
The network type of the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number of the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#publicly_accessible ⇒ Boolean
Indicates whether the resource was publicly accessible at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
The VPC security group IDs associated with the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |
#vpc_subnet_ids ⇒ Array<String>
The VPC subnet IDs associated with the resource at the time of backup.
1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1692 class GetDbBackupOutput < Struct.new( :id, :name, :arn, :status, :created_at, :expires_after, :db_resource_id, :type, :engine_type, :deployment_type, :kms_key_id, :cluster_configuration, :db_parameter_group_id, :db_instance_type, :log_delivery_configuration, :failover_mode, :db_storage_type, :allocated_storage, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :port, :network_type, :influx_auth_parameters_secret_arn, :maintenance_schedule) SENSITIVE = [] include Aws::Structure end |