Class: Aws::TimestreamInfluxDB::Types::GetDbClusterOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

The amount of storage allocated for your DB storage type (in gibibytes).

Returns:

  • (Integer)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the DB cluster.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_configurationTypes::ClusterConfiguration

Configuration for node modes in the DbCluster.



1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_backup_configurationsArray<Types::DbBackupConfigurationOutput>

The backup configurations for the DB cluster.



1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_typeString

The Timestream for InfluxDB instance type that InfluxDB runs on.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_parameter_group_identifierString

The ID of the DB parameter group assigned to your DB cluster.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_storage_typeString

The Timestream for InfluxDB DB storage type that InfluxDB stores data on.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_typeString

Deployment type of the DB cluster.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#endpointString

The endpoint used to connect to the Timestream for InfluxDB cluster for write and read operations.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#engine_typeString

The engine type of your DB cluster.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#failover_modeString

The configured failover mode for the DB cluster.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Service-generated unique identifier of the DB cluster to retrieve.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#influx_auth_parameters_secret_arnString

The Amazon Resource Name (ARN) of the Secrets Manager secret containing the initial InfluxDB authorization parameters. The secret value is a JSON formatted key-value pair holding InfluxDB authorization values: organization, bucket, username, and password.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Web Services KMS key ARN used for encryption of the DB cluster.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#last_maintenance_timeTime

The timestamp of the last completed maintenance operation on the DB cluster.

Returns:

  • (Time)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_configurationTypes::LogDeliveryConfiguration

Configuration for sending InfluxDB engine logs to send to specified S3 bucket.



1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_scheduleTypes::MaintenanceSchedule

The maintenance schedule for the DB cluster.



1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Customer-supplied name of the Timestream for InfluxDB cluster.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_typeString

Specifies whether the network type of the Timestream for InfluxDB cluster is IPv4, which can communicate over IPv4 protocol only, or DUAL, which can communicate over both IPv4 and IPv6 protocols.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_maintenance_timeTime

The timestamp of the next scheduled maintenance operation on the DB cluster.

Returns:

  • (Time)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port number on which InfluxDB accepts connections.

Returns:

  • (Integer)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#publicly_accessibleBoolean

Indicates if the DB cluster has a public IP to facilitate access from outside the VPC.

Returns:

  • (Boolean)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#reader_endpointString

The endpoint used to connect to the Timestream for InfluxDB cluster for read-only operations.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the DB cluster.

Returns:

  • (String)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_security_group_idsArray<String>

A list of VPC security group IDs associated with the DB cluster.

Returns:

  • (Array<String>)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_subnet_idsArray<String>

A list of VPC subnet IDs associated with the DB cluster.

Returns:

  • (Array<String>)


1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1854

class GetDbClusterOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :endpoint,
  :reader_endpoint,
  :port,
  :deployment_type,
  :db_instance_type,
  :network_type,
  :db_storage_type,
  :allocated_storage,
  :engine_type,
  :publicly_accessible,
  :db_parameter_group_identifier,
  :log_delivery_configuration,
  :maintenance_schedule,
  :last_maintenance_time,
  :next_maintenance_time,
  :influx_auth_parameters_secret_arn,
  :vpc_subnet_ids,
  :vpc_security_group_ids,
  :failover_mode,
  :cluster_configuration,
  :db_backup_configurations,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end