Class: Aws::TimestreamInfluxDB::Types::RestoreFromDbBackupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::RestoreFromDbBackupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_backup_configurations ⇒ Array<Types::DbBackupConfiguration>
A list of backup configurations to apply to the restored resource.
-
#db_backup_id ⇒ String
The identifier of the backup to restore from.
-
#deployment_type ⇒ String
Specifies the deployment type of the restored resource.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier to use for encryption of the restored resource.
-
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to the specified S3 bucket for the restored resource.
-
#maintenance_schedule ⇒ Types::MaintenanceSchedule
The maintenance schedule for the restored resource.
-
#name ⇒ String
The name of the new resource to create from the restore.
-
#network_type ⇒ String
Specifies the network type of the restored resource.
-
#port ⇒ Integer
The port number on which the restored InfluxDB resource accepts connections.
-
#publicly_accessible ⇒ Boolean
Specifies whether the restored resource is publicly accessible.
-
#restore_mode ⇒ String
Specifies whether to restore to a new resource or replace the existing resource.
-
#restore_to_time ⇒ Time
The point in time to restore to, for continuous backups.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs to associate with the restored resource.
-
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security group IDs for the restored resource.
-
#vpc_subnet_ids ⇒ Array<String>
A list of VPC subnet IDs for the restored resource.
Instance Attribute Details
#db_backup_configurations ⇒ Array<Types::DbBackupConfiguration>
A list of backup configurations to apply to the restored resource.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#db_backup_id ⇒ String
The identifier of the backup to restore from.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#deployment_type ⇒ String
Specifies the deployment type of the restored resource. Valid values are SINGLE_AZ, WITH_MULTIAZ_STANDBY, and MULTI_NODE_READ_REPLICAS.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier to use for encryption of the restored resource. Can be a key ID, key ARN, alias name, or alias ARN.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to the specified S3 bucket for the restored resource.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#maintenance_schedule ⇒ Types::MaintenanceSchedule
The maintenance schedule for the restored resource.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the new resource to create from the restore. If restoring to an existing resource, the name must match the existing resource name.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
Specifies the network type of the restored resource. Valid values are IPV4 and DUAL.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which the restored InfluxDB resource accepts connections.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#publicly_accessible ⇒ Boolean
Specifies whether the restored resource is publicly accessible.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#restore_mode ⇒ String
Specifies whether to restore to a new resource or replace the existing resource. Valid values are NEW_RESOURCE (default) and REPLACE_EXISTING.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#restore_to_time ⇒ Time
The point in time to restore to, for continuous backups. Must be within the backup's retention window.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs to associate with the restored resource.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security group IDs for the restored resource. If not specified, the restored resource uses the same security groups as the backup.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#vpc_subnet_ids ⇒ Array<String>
A list of VPC subnet IDs for the restored resource. If not specified, the restored resource uses the same subnets as the backup.
3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 3791 class RestoreFromDbBackupInput < Struct.new( :name, :db_backup_id, :restore_to_time, :restore_mode, :vpc_subnet_ids, :vpc_security_group_ids, :publicly_accessible, :log_delivery_configuration, :maintenance_schedule, :tags, :port, :network_type, :deployment_type, :db_backup_configurations, :kms_key_id) SENSITIVE = [] include Aws::Structure end |