Class: Aws::TimestreamInfluxDB::Types::UpdateDbInstanceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::UpdateDbInstanceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The amount of storage to allocate for your DB storage type (in gibibytes).
-
#db_backup_configurations ⇒ Array<Types::DbBackupConfiguration>
A list of backup configurations to update for the DB instance.
-
#db_instance_type ⇒ String
The Timestream for InfluxDB DB instance type to run InfluxDB on.
-
#db_parameter_group_identifier ⇒ String
The id of the DB parameter group to assign to your DB instance.
-
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type that InfluxDB stores data on.
-
#deployment_type ⇒ String
Specifies whether the DB instance will be deployed as a standalone instance or with a Multi-AZ standby for high availability.
-
#identifier ⇒ String
The id of the DB instance.
-
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to send to specified S3 bucket.
-
#maintenance_schedule ⇒ Types::MaintenanceSchedule
Specifies the maintenance schedule for the DB instance, including the preferred maintenance window and timezone.
-
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
Instance Attribute Details
#allocated_storage ⇒ Integer
The amount of storage to allocate for your DB storage type (in gibibytes).
4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 4047 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :port, :db_instance_type, :deployment_type, :db_storage_type, :allocated_storage, :maintenance_schedule, :db_backup_configurations) SENSITIVE = [] include Aws::Structure end |
#db_backup_configurations ⇒ Array<Types::DbBackupConfiguration>
A list of backup configurations to update for the DB instance.
4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 4047 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :port, :db_instance_type, :deployment_type, :db_storage_type, :allocated_storage, :maintenance_schedule, :db_backup_configurations) SENSITIVE = [] include Aws::Structure end |
#db_instance_type ⇒ String
The Timestream for InfluxDB DB instance type to run InfluxDB on.
4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 4047 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :port, :db_instance_type, :deployment_type, :db_storage_type, :allocated_storage, :maintenance_schedule, :db_backup_configurations) SENSITIVE = [] include Aws::Structure end |
#db_parameter_group_identifier ⇒ String
The id of the DB parameter group to assign to your DB instance. DB parameter groups specify how the database is configured. For example, DB parameter groups can specify the limit for query concurrency.
4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 4047 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :port, :db_instance_type, :deployment_type, :db_storage_type, :allocated_storage, :maintenance_schedule, :db_backup_configurations) SENSITIVE = [] include Aws::Structure end |
#db_storage_type ⇒ String
The Timestream for InfluxDB DB storage type that InfluxDB stores data on.
4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 4047 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :port, :db_instance_type, :deployment_type, :db_storage_type, :allocated_storage, :maintenance_schedule, :db_backup_configurations) SENSITIVE = [] include Aws::Structure end |
#deployment_type ⇒ String
Specifies whether the DB instance will be deployed as a standalone instance or with a Multi-AZ standby for high availability.
4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 4047 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :port, :db_instance_type, :deployment_type, :db_storage_type, :allocated_storage, :maintenance_schedule, :db_backup_configurations) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The id of the DB instance.
4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 4047 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :port, :db_instance_type, :deployment_type, :db_storage_type, :allocated_storage, :maintenance_schedule, :db_backup_configurations) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to send to specified S3 bucket.
4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 4047 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :port, :db_instance_type, :deployment_type, :db_storage_type, :allocated_storage, :maintenance_schedule, :db_backup_configurations) SENSITIVE = [] include Aws::Structure end |
#maintenance_schedule ⇒ Types::MaintenanceSchedule
Specifies the maintenance schedule for the DB instance, including the preferred maintenance window and timezone.
4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 4047 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :port, :db_instance_type, :deployment_type, :db_storage_type, :allocated_storage, :maintenance_schedule, :db_backup_configurations) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which InfluxDB accepts connections.
If you change the Port value, your database restarts immediately.
Valid Values: 1024-65535
Default: 8086
Constraints: The value can't be 2375-2376, 7788-7799, 8090, or 51678-51680
4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 4047 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :port, :db_instance_type, :deployment_type, :db_storage_type, :allocated_storage, :maintenance_schedule, :db_backup_configurations) SENSITIVE = [] include Aws::Structure end |