Class: Aws::TimestreamInfluxDB::Types::UpdateDbInstanceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

The amount of storage to allocate for your DB storage type (in gibibytes).

Returns:

  • (Integer)


1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1415

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :deployment_type,
  :db_storage_type,
  :allocated_storage)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_typeString

The Timestream for InfluxDB DB instance type to run InfluxDB on.

Returns:

  • (String)


1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1415

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :deployment_type,
  :db_storage_type,
  :allocated_storage)
  SENSITIVE = []
  include Aws::Structure
end

#db_parameter_group_identifierString

The id of the DB parameter group to assign to your DB instance. DB parameter groups specify how the database is configured. For example, DB parameter groups can specify the limit for query concurrency.

Returns:

  • (String)


1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1415

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :deployment_type,
  :db_storage_type,
  :allocated_storage)
  SENSITIVE = []
  include Aws::Structure
end

#db_storage_typeString

The Timestream for InfluxDB DB storage type that InfluxDB stores data on.

Returns:

  • (String)


1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1415

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :deployment_type,
  :db_storage_type,
  :allocated_storage)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_typeString

Specifies whether the DB instance will be deployed as a standalone instance or with a Multi-AZ standby for high availability.

Returns:

  • (String)


1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1415

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :deployment_type,
  :db_storage_type,
  :allocated_storage)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The id of the DB instance.

Returns:

  • (String)


1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1415

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :deployment_type,
  :db_storage_type,
  :allocated_storage)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_configurationTypes::LogDeliveryConfiguration

Configuration for sending InfluxDB engine logs to send to specified S3 bucket.



1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1415

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :deployment_type,
  :db_storage_type,
  :allocated_storage)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port number on which InfluxDB accepts connections.

If you change the Port value, your database restarts immediately.

Valid Values: 1024-65535

Default: 8086

Constraints: The value can’t be 2375-2376, 7788-7799, 8090, or 51678-51680

Returns:

  • (Integer)


1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1415

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :port,
  :db_instance_type,
  :deployment_type,
  :db_storage_type,
  :allocated_storage)
  SENSITIVE = []
  include Aws::Structure
end