Class: Aws::TimestreamInfluxDB::Types::UpdateDbInstanceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreaminfluxdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_instance_typeString

The Timestream for InfluxDB DB instance type to run InfluxDB on.

Returns:

  • (String)


1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1060

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :db_instance_type,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#db_parameter_group_identifierString

The id of the DB parameter group to assign to your DB instance. DB parameter groups specify how the database is configured. For example, DB parameter groups can specify the limit for query concurrency.

Returns:

  • (String)


1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1060

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :db_instance_type,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_typeString

Specifies whether the DB instance will be deployed as a standalone instance or with a Multi-AZ standby for high availability.

Returns:

  • (String)


1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1060

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :db_instance_type,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The id of the DB instance.

Returns:

  • (String)


1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1060

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :db_instance_type,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_configurationTypes::LogDeliveryConfiguration

Configuration for sending InfluxDB engine logs to send to specified S3 bucket.



1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1060

class UpdateDbInstanceInput < Struct.new(
  :identifier,
  :log_delivery_configuration,
  :db_parameter_group_identifier,
  :db_instance_type,
  :deployment_type)
  SENSITIVE = []
  include Aws::Structure
end