Class: Aws::TimestreamInfluxDB::Types::UpdateDbInstanceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::TimestreamInfluxDB::Types::UpdateDbInstanceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-timestreaminfluxdb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_instance_type ⇒ String
The Timestream for InfluxDB DB instance type to run InfluxDB on.
-
#db_parameter_group_identifier ⇒ String
The id of the DB parameter group to assign to your DB instance.
-
#deployment_type ⇒ String
Specifies whether the DB instance will be deployed as a standalone instance or with a Multi-AZ standby for high availability.
-
#identifier ⇒ String
The id of the DB instance.
-
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to send to specified S3 bucket.
Instance Attribute Details
#db_instance_type ⇒ String
The Timestream for InfluxDB DB instance type to run InfluxDB on.
1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1060 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :db_instance_type, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#db_parameter_group_identifier ⇒ String
The id of the DB parameter group to assign to your DB instance. DB parameter groups specify how the database is configured. For example, DB parameter groups can specify the limit for query concurrency.
1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1060 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :db_instance_type, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#deployment_type ⇒ String
Specifies whether the DB instance will be deployed as a standalone instance or with a Multi-AZ standby for high availability.
1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1060 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :db_instance_type, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The id of the DB instance.
1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1060 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :db_instance_type, :deployment_type) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configuration ⇒ Types::LogDeliveryConfiguration
Configuration for sending InfluxDB engine logs to send to specified S3 bucket.
1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-timestreaminfluxdb/types.rb', line 1060 class UpdateDbInstanceInput < Struct.new( :identifier, :log_delivery_configuration, :db_parameter_group_identifier, :db_instance_type, :deployment_type) SENSITIVE = [] include Aws::Structure end |